user_translatable_label — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

# user_translatable_label

class `camelot.view.controls.user_translatable_label.` `UserTranslatableLabel`(text, parent=None)

  A QLabel that allows the user to translate the text contained within by right clicking on it and selecting the appropriate submenu.

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

Comments
blog comments powered by Disqus